Class: ILoveVideoEditor::CreateCheckoutSessionRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateCheckoutSessionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::CreateCheckoutSessionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::CreateCheckoutSessionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'product_id')
    self.product_id = attributes[:'product_id']
  end

  if attributes.key?(:'tier_id')
    self.tier_id = attributes[:'tier_id']
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'credits')
    self.credits = attributes[:'credits']
  end

  if attributes.key?(:'amount_eur')
    self.amount_eur = attributes[:'amount_eur']
  end
end

Instance Attribute Details

#amount_eurObject

Custom credit top-up amount in EUR (mode=payment only). Between 10 and 2500, at most 2 decimal places. When set, the pay-what-you-want credits product is used and any productId is ignored.



27
28
29
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 27

def amount_eur
  @amount_eur
end

#creditsObject

Returns the value of attribute credits.



24
25
26
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 24

def credits
  @credits
end

#modeObject

Returns the value of attribute mode.



22
23
24
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 22

def mode
  @mode
end

#product_idObject

Returns the value of attribute product_id.



18
19
20
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 18

def product_id
  @product_id
end

#tier_idObject

Returns the value of attribute tier_id.



20
21
22
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 20

def tier_id
  @tier_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 52

def self.attribute_map
  {
    :'product_id' => :'productId',
    :'tier_id' => :'tierId',
    :'mode' => :'mode',
    :'credits' => :'credits',
    :'amount_eur' => :'amountEur'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 73

def self.openapi_types
  {
    :'product_id' => :'String',
    :'tier_id' => :'String',
    :'mode' => :'String',
    :'credits' => :'Integer',
    :'amount_eur' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



167
168
169
170
171
172
173
174
175
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 167

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      product_id == o.product_id &&
      tier_id == o.tier_id &&
      mode == o.mode &&
      credits == o.credits &&
      amount_eur == o.amount_eur
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 185

def hash
  [product_id, tier_id, mode, credits, amount_eur].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



136
137
138
139
140
141
142
143
# File 'lib/generated/ilovevideoeditor-sdk/models/create_checkout_session_request.rb', line 136

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  tier_id_validator = EnumAttributeValidator.new('String', ["free", "starter", "pro", "business"])
  return false unless tier_id_validator.valid?(@tier_id)
  mode_validator = EnumAttributeValidator.new('String', ["subscription", "payment"])
  return false unless mode_validator.valid?(@mode)
  true
end