Class: ILoveVideoEditor::ProjectUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/project_update.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProjectUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::ProjectUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::ProjectUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'video_json')
    self.video_json = attributes[:'video_json']
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end

  if attributes.key?(:'thumbnail_base64')
    self.thumbnail_base64 = attributes[:'thumbnail_base64']
  end

  if attributes.key?(:'sprite_url')
    self.sprite_url = attributes[:'sprite_url']
  end

  if attributes.key?(:'sprite_base64')
    self.sprite_base64 = attributes[:'sprite_base64']
  end

  if attributes.key?(:'last_opened_at')
    self.last_opened_at = attributes[:'last_opened_at']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



20
21
22
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 20

def description
  @description
end

#durationObject

Returns the value of attribute duration.



36
37
38
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 36

def duration
  @duration
end

#heightObject

Returns the value of attribute height.



40
41
42
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 40

def height
  @height
end

#last_opened_atObject

Returns the value of attribute last_opened_at.



34
35
36
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 34

def last_opened_at
  @last_opened_at
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 18

def name
  @name
end

#sprite_base64Object

Base64-encoded sprite sheet. Uploaded to Bunny Storage.



32
33
34
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 32

def sprite_base64
  @sprite_base64
end

#sprite_urlObject

Returns the value of attribute sprite_url.



29
30
31
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 29

def sprite_url
  @sprite_url
end

#thumbnail_base64Object

Base64-encoded thumbnail image. Uploaded to Bunny Storage.



27
28
29
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 27

def thumbnail_base64
  @thumbnail_base64
end

#thumbnail_urlObject

Returns the value of attribute thumbnail_url.



24
25
26
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 24

def thumbnail_url
  @thumbnail_url
end

#video_jsonObject

Returns the value of attribute video_json.



22
23
24
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 22

def video_json
  @video_json
end

#widthObject

Returns the value of attribute width.



38
39
40
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 38

def width
  @width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 43

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'video_json' => :'video_json',
    :'thumbnail_url' => :'thumbnail_url',
    :'thumbnail_base64' => :'thumbnail_base64',
    :'sprite_url' => :'sprite_url',
    :'sprite_base64' => :'sprite_base64',
    :'last_opened_at' => :'last_opened_at',
    :'duration' => :'duration',
    :'width' => :'width',
    :'height' => :'height'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 201

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 70

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'video_json' => :'Object',
    :'thumbnail_url' => :'String',
    :'thumbnail_base64' => :'String',
    :'sprite_url' => :'String',
    :'sprite_base64' => :'String',
    :'last_opened_at' => :'Time',
    :'duration' => :'Integer',
    :'width' => :'Integer',
    :'height' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      video_json == o.video_json &&
      thumbnail_url == o.thumbnail_url &&
      thumbnail_base64 == o.thumbnail_base64 &&
      sprite_url == o.sprite_url &&
      sprite_base64 == o.sprite_base64 &&
      last_opened_at == o.last_opened_at &&
      duration == o.duration &&
      width == o.width &&
      height == o.height
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 194

def hash
  [name, description, video_json, thumbnail_url, thumbnail_base64, sprite_url, sprite_base64, last_opened_at, duration, width, height].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
# File 'lib/generated/ilovevideoeditor-sdk/models/project_update.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end