Class: ILoveVideoEditor::RenderApi

Inherits:
Object
  • Object
show all
Defined in:
lib/generated/ilovevideoeditor-sdk/api/render_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RenderApi

Returns a new instance of RenderApi.



19
20
21
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#cancel_render(id, opts = {}) ⇒ CancelRender200Response

Cancel a render job Cancels a render job that has not reached a terminal state.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 27

def cancel_render(id, opts = {})
  data, _status_code, _headers = cancel_render_with_http_info(id, opts)
  data
end

#cancel_render_with_http_info(id, opts = {}) ⇒ Array<(CancelRender200Response, Integer, Hash)>

Cancel a render job Cancels a render job that has not reached a terminal state.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CancelRender200Response, Integer, Hash)>)

    CancelRender200Response data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 37

def cancel_render_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.cancel_render ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling RenderApi.cancel_render"
  end
  # resource path
  local_var_path = '/v1/render/{id}/cancel'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CancelRender200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.cancel_render",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#cancel_render\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_render(id, opts = {}) ⇒ nil

Download rendered video Redirects to the signed CDN URL for the completed render.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


90
91
92
93
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 90

def download_render(id, opts = {})
  download_render_with_http_info(id, opts)
  nil
end

#download_render_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Download rendered video Redirects to the signed CDN URL for the completed render.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 100

def download_render_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.download_render ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling RenderApi.download_render"
  end
  # resource path
  local_var_path = '/v1/render/{id}/download'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.download_render",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#download_render\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#estimate_render_cost(estimate_render_cost_request, opts = {}) ⇒ RenderCostEstimate

Estimate render cost

Parameters:

Returns:



152
153
154
155
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 152

def estimate_render_cost(estimate_render_cost_request, opts = {})
  data, _status_code, _headers = estimate_render_cost_with_http_info(estimate_render_cost_request, opts)
  data
end

#estimate_render_cost_with_http_info(estimate_render_cost_request, opts = {}) ⇒ Array<(RenderCostEstimate, Integer, Hash)>

Estimate render cost

Parameters:

Returns:

  • (Array<(RenderCostEstimate, Integer, Hash)>)

    RenderCostEstimate data, response status code and response headers



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 161

def estimate_render_cost_with_http_info(estimate_render_cost_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.estimate_render_cost ...'
  end
  # verify the required parameter 'estimate_render_cost_request' is set
  if @api_client.config.client_side_validation && estimate_render_cost_request.nil?
    fail ArgumentError, "Missing the required parameter 'estimate_render_cost_request' when calling RenderApi.estimate_render_cost"
  end
  # resource path
  local_var_path = '/v1/render/cost'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(estimate_render_cost_request)

  # return_type
  return_type = opts[:debug_return_type] || 'RenderCostEstimate'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.estimate_render_cost",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#estimate_render_cost\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_render_download_url(id, opts = {}) ⇒ GetRenderDownloadUrl200Response

Get rendered video download URL

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



218
219
220
221
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 218

def get_render_download_url(id, opts = {})
  data, _status_code, _headers = get_render_download_url_with_http_info(id, opts)
  data
end

#get_render_download_url_with_http_info(id, opts = {}) ⇒ Array<(GetRenderDownloadUrl200Response, Integer, Hash)>

Get rendered video download URL

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 227

def get_render_download_url_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.get_render_download_url ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling RenderApi.get_render_download_url"
  end
  # resource path
  local_var_path = '/v1/render/{id}/download-url'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetRenderDownloadUrl200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.get_render_download_url",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#get_render_download_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_render_status(id, opts = {}) ⇒ RenderJob

Get render job status

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



279
280
281
282
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 279

def get_render_status(id, opts = {})
  data, _status_code, _headers = get_render_status_with_http_info(id, opts)
  data
end

#get_render_status_with_http_info(id, opts = {}) ⇒ Array<(RenderJob, Integer, Hash)>

Get render job status

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RenderJob, Integer, Hash)>)

    RenderJob data, response status code and response headers



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 288

def get_render_status_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.get_render_status ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling RenderApi.get_render_status"
  end
  # resource path
  local_var_path = '/v1/render/{id}'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RenderJob'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.get_render_status",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#get_render_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_render_tier(opts = {}) ⇒ TierInfo

Get workspace render tier

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



339
340
341
342
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 339

def get_render_tier(opts = {})
  data, _status_code, _headers = get_render_tier_with_http_info(opts)
  data
end

#get_render_tier_with_http_info(opts = {}) ⇒ Array<(TierInfo, Integer, Hash)>

Get workspace render tier

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TierInfo, Integer, Hash)>)

    TierInfo data, response status code and response headers



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 347

def get_render_tier_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.get_render_tier ...'
  end
  # resource path
  local_var_path = '/v1/render/tier'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TierInfo'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.get_render_tier",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#get_render_tier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_renders(opts = {}) ⇒ Array<RenderListItem>

List recent renders

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer) — default: default to 10

Returns:



395
396
397
398
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 395

def list_renders(opts = {})
  data, _status_code, _headers = list_renders_with_http_info(opts)
  data
end

#list_renders_with_http_info(opts = {}) ⇒ Array<(Array<RenderListItem>, Integer, Hash)>

List recent renders

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer) — default: default to 10

Returns:

  • (Array<(Array<RenderListItem>, Integer, Hash)>)

    Array data, response status code and response headers



404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 404

def list_renders_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.list_renders ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 50
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling RenderApi.list_renders, must be smaller than or equal to 50.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling RenderApi.list_renders, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v1/render'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<RenderListItem>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.list_renders",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#list_renders\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#queue_render(queue_render_request, opts = {}) ⇒ QueueRender200Response

Queue a render job Submit a VideoJSON payload to be rendered to MP4.

Parameters:

  • queue_render_request (QueueRenderRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Optional idempotency key (max 128 chars, 24h replay window).

Returns:



463
464
465
466
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 463

def queue_render(queue_render_request, opts = {})
  data, _status_code, _headers = queue_render_with_http_info(queue_render_request, opts)
  data
end

#queue_render_with_http_info(queue_render_request, opts = {}) ⇒ Array<(QueueRender200Response, Integer, Hash)>

Queue a render job Submit a `VideoJSON` payload to be rendered to MP4.

Parameters:

  • queue_render_request (QueueRenderRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Optional idempotency key (max 128 chars, 24h replay window).

Returns:

  • (Array<(QueueRender200Response, Integer, Hash)>)

    QueueRender200Response data, response status code and response headers



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 474

def queue_render_with_http_info(queue_render_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.queue_render ...'
  end
  # verify the required parameter 'queue_render_request' is set
  if @api_client.config.client_side_validation && queue_render_request.nil?
    fail ArgumentError, "Missing the required parameter 'queue_render_request' when calling RenderApi.queue_render"
  end
  if @api_client.config.client_side_validation && !opts[:'idempotency_key'].nil? && opts[:'idempotency_key'].to_s.length > 128
    fail ArgumentError, 'invalid value for "opts[:"idempotency_key"]" when calling RenderApi.queue_render, the character length must be smaller than or equal to 128.'
  end

  # resource path
  local_var_path = '/v1/render'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(queue_render_request)

  # return_type
  return_type = opts[:debug_return_type] || 'QueueRender200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.queue_render",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#queue_render\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#refresh_render_url(id, opts = {}) ⇒ RefreshRenderUrl200Response

Refresh signed download URL

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



536
537
538
539
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 536

def refresh_render_url(id, opts = {})
  data, _status_code, _headers = refresh_render_url_with_http_info(id, opts)
  data
end

#refresh_render_url_with_http_info(id, opts = {}) ⇒ Array<(RefreshRenderUrl200Response, Integer, Hash)>

Refresh signed download URL

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RefreshRenderUrl200Response, Integer, Hash)>)

    RefreshRenderUrl200Response data, response status code and response headers



545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 545

def refresh_render_url_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.refresh_render_url ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling RenderApi.refresh_render_url"
  end
  # resource path
  local_var_path = '/v1/render/{id}/refresh-url'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RefreshRenderUrl200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.refresh_render_url",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#refresh_render_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#track_render_bandwidth(id, opts = {}) ⇒ TrackRenderBandwidth200Response

Track render download bandwidth Records bandwidth usage for renders streamed directly from the CDN.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



598
599
600
601
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 598

def track_render_bandwidth(id, opts = {})
  data, _status_code, _headers = track_render_bandwidth_with_http_info(id, opts)
  data
end

#track_render_bandwidth_with_http_info(id, opts = {}) ⇒ Array<(TrackRenderBandwidth200Response, Integer, Hash)>

Track render download bandwidth Records bandwidth usage for renders streamed directly from the CDN.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
# File 'lib/generated/ilovevideoeditor-sdk/api/render_api.rb', line 608

def track_render_bandwidth_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RenderApi.track_render_bandwidth ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling RenderApi.track_render_bandwidth"
  end
  # resource path
  local_var_path = '/v1/render/{id}/track-bandwidth'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TrackRenderBandwidth200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth']

  new_options = opts.merge(
    :operation => :"RenderApi.track_render_bandwidth",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#track_render_bandwidth\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end