Class: ILoveVideoEditor::RenderListItem

Inherits:
ApiModelBase show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb

Overview

Flat render summary as returned by GET /v1/render.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RenderListItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::RenderListItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::RenderListItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'stage')
    self.stage = attributes[:'stage']
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  else
    self.progress = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end

  if attributes.key?(:'sprite_url')
    self.sprite_url = attributes[:'sprite_url']
  end

  if attributes.key?(:'cost')
    self.cost = attributes[:'cost']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end
end

Instance Attribute Details

#completed_atObject

Returns the value of attribute completed_at.



36
37
38
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 36

def completed_at
  @completed_at
end

#costObject

Credits charged for the render.



42
43
44
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 42

def cost
  @cost
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 34

def created_at
  @created_at
end

#durationObject

Render duration in seconds.



45
46
47
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 45

def duration
  @duration
end

#errorObject

Returns the value of attribute error.



32
33
34
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 32

def error
  @error
end

#heightObject

Returns the value of attribute height.



49
50
51
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 49

def height
  @height
end

#idObject

Render job ID.



20
21
22
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 20

def id
  @id
end

#progressObject

Returns the value of attribute progress.



27
28
29
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 27

def progress
  @progress
end

#sprite_urlObject

Hover-preview sprite sheet URL, when generated.



39
40
41
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 39

def sprite_url
  @sprite_url
end

#stageObject

Granular pipeline stage; omitted when unknown.



25
26
27
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 25

def stage
  @stage
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 22

def status
  @status
end

#urlObject

Download URL of the rendered MP4 (completed only).



30
31
32
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 30

def url
  @url
end

#widthObject

Returns the value of attribute width.



47
48
49
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 47

def width
  @width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 52

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'stage' => :'stage',
    :'progress' => :'progress',
    :'url' => :'url',
    :'error' => :'error',
    :'created_at' => :'createdAt',
    :'completed_at' => :'completedAt',
    :'sprite_url' => :'spriteUrl',
    :'cost' => :'cost',
    :'duration' => :'duration',
    :'width' => :'width',
    :'height' => :'height'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 318

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 100

def self.openapi_nullable
  Set.new([
    :'url',
    :'error',
    :'completed_at',
    :'sprite_url',
    :'cost',
    :'duration',
    :'width',
    :'height'
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'status' => :'String',
    :'stage' => :'String',
    :'progress' => :'Integer',
    :'url' => :'String',
    :'error' => :'String',
    :'created_at' => :'Time',
    :'completed_at' => :'Time',
    :'sprite_url' => :'String',
    :'cost' => :'Float',
    :'duration' => :'Float',
    :'width' => :'Integer',
    :'height' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 285

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      stage == o.stage &&
      progress == o.progress &&
      url == o.url &&
      error == o.error &&
      created_at == o.created_at &&
      completed_at == o.completed_at &&
      sprite_url == o.sprite_url &&
      cost == o.cost &&
      duration == o.duration &&
      width == o.width &&
      height == o.height
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


305
306
307
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 305

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



311
312
313
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 311

def hash
  [id, status, stage, progress, url, error, created_at, completed_at, sprite_url, cost, duration, width, height].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @progress.nil?
    invalid_properties.push('invalid value for "progress", progress cannot be nil.')
  end

  if @progress > 100
    invalid_properties.push('invalid value for "progress", must be smaller than or equal to 100.')
  end

  if @progress < 0
    invalid_properties.push('invalid value for "progress", must be greater than or equal to 0.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 340

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
230
231
232
233
# File 'lib/generated/ilovevideoeditor-sdk/models/render_list_item.rb', line 224

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @status.nil?
  return false if @progress.nil?
  return false if @progress > 100
  return false if @progress < 0
  return false if @created_at.nil?
  true
end