Class: ILoveVideoEditor::RenderWebhookPayload

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb

Overview

JSON body POSTed to webhook targets on terminal render states.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RenderWebhookPayload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::RenderWebhookPayload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::RenderWebhookPayload`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'stage')
    self.stage = attributes[:'stage']
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'outputs')
    if (value = attributes[:'outputs']).is_a?(Array)
      self.outputs = value
    end
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'cost')
    self.cost = attributes[:'cost']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end
end

Instance Attribute Details

#completed_atObject

Returns the value of attribute completed_at.



48
49
50
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 48

def completed_at
  @completed_at
end

#costObject

Returns the value of attribute cost.



42
43
44
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 42

def cost
  @cost
end

#created_atObject

Returns the value of attribute created_at.



46
47
48
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 46

def created_at
  @created_at
end

#durationObject

Returns the value of attribute duration.



34
35
36
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 34

def duration
  @duration
end

#errorObject

Returns the value of attribute error.



44
45
46
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 44

def error
  @error
end

#eventObject

Returns the value of attribute event.



19
20
21
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 19

def event
  @event
end

#heightObject

Returns the value of attribute height.



38
39
40
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 38

def height
  @height
end

#idObject

Render job ID.



22
23
24
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 22

def id
  @id
end

#outputsObject

Returns the value of attribute outputs.



32
33
34
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 32

def outputs
  @outputs
end

#progressObject

Returns the value of attribute progress.



28
29
30
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 28

def progress
  @progress
end

#stageObject

Returns the value of attribute stage.



26
27
28
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 26

def stage
  @stage
end

#statusObject

Returns the value of attribute status.



24
25
26
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 24

def status
  @status
end

#template_idObject

Returns the value of attribute template_id.



40
41
42
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 40

def template_id
  @template_id
end

#urlObject

Returns the value of attribute url.



30
31
32
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 30

def url
  @url
end

#widthObject

Returns the value of attribute width.



36
37
38
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 36

def width
  @width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



94
95
96
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 94

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 99

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 73

def self.attribute_map
  {
    :'event' => :'event',
    :'id' => :'id',
    :'status' => :'status',
    :'stage' => :'stage',
    :'progress' => :'progress',
    :'url' => :'url',
    :'outputs' => :'outputs',
    :'duration' => :'duration',
    :'width' => :'width',
    :'height' => :'height',
    :'template_id' => :'templateId',
    :'cost' => :'cost',
    :'error' => :'error',
    :'created_at' => :'createdAt',
    :'completed_at' => :'completedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 319

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



125
126
127
128
129
130
131
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 125

def self.openapi_nullable
  Set.new([
    :'url',
    :'error',
    :'completed_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 104

def self.openapi_types
  {
    :'event' => :'String',
    :'id' => :'String',
    :'status' => :'String',
    :'stage' => :'String',
    :'progress' => :'Integer',
    :'url' => :'String',
    :'outputs' => :'Array<Hash<String, Object>>',
    :'duration' => :'Float',
    :'width' => :'Integer',
    :'height' => :'Integer',
    :'template_id' => :'String',
    :'cost' => :'Float',
    :'error' => :'String',
    :'created_at' => :'Time',
    :'completed_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      event == o.event &&
      id == o.id &&
      status == o.status &&
      stage == o.stage &&
      progress == o.progress &&
      url == o.url &&
      outputs == o.outputs &&
      duration == o.duration &&
      width == o.width &&
      height == o.height &&
      template_id == o.template_id &&
      cost == o.cost &&
      error == o.error &&
      created_at == o.created_at &&
      completed_at == o.completed_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


306
307
308
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 306

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



312
313
314
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 312

def hash
  [event, id, status, stage, progress, url, outputs, duration, width, height, template_id, cost, error, created_at, completed_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 220

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 341

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



240
241
242
243
244
245
246
247
248
249
250
# File 'lib/generated/ilovevideoeditor-sdk/models/render_webhook_payload.rb', line 240

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @event.nil?
  event_validator = EnumAttributeValidator.new('String', ["render.completed", "render.failed"])
  return false unless event_validator.valid?(@event)
  return false if @id.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["completed", "failed"])
  return false unless status_validator.valid?(@status)
  true
end