Class: ILoveVideoEditor::Rendition

Inherits:
ApiModelBase show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/rendition.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Rendition

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::Rendition` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::Rendition`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'job_id')
    self.job_id = attributes[:'job_id']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'stage')
    self.stage = attributes[:'stage']
  end

  if attributes.key?(:'cost')
    self.cost = attributes[:'cost']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'fps')
    self.fps = attributes[:'fps']
  end

  if attributes.key?(:'output_url')
    self.output_url = attributes[:'output_url']
  end

  if attributes.key?(:'output_size_bytes')
    self.output_size_bytes = attributes[:'output_size_bytes']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'progress_percent')
    self.progress_percent = attributes[:'progress_percent']
  end

  if attributes.key?(:'sprite_url')
    self.sprite_url = attributes[:'sprite_url']
  end

  if attributes.key?(:'video_json')
    self.video_json = attributes[:'video_json']
  end

  if attributes.key?(:'outputs')
    if (value = attributes[:'outputs']).is_a?(Array)
      self.outputs = value
    end
  end

  if attributes.key?(:'projects')
    self.projects = attributes[:'projects']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end
end

Instance Attribute Details

#completed_atObject

Returns the value of attribute completed_at.



56
57
58
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 56

def completed_at
  @completed_at
end

#costObject

Returns the value of attribute cost.



28
29
30
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 28

def cost
  @cost
end

#created_atObject

Returns the value of attribute created_at.



54
55
56
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 54

def created_at
  @created_at
end

#durationObject

Returns the value of attribute duration.



30
31
32
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 30

def duration
  @duration
end

#errorObject

Returns the value of attribute error.



42
43
44
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 42

def error
  @error
end

#fpsObject

Returns the value of attribute fps.



36
37
38
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 36

def fps
  @fps
end

#heightObject

Returns the value of attribute height.



34
35
36
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 34

def height
  @height
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 18

def id
  @id
end

#job_idObject

Returns the value of attribute job_id.



20
21
22
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 20

def job_id
  @job_id
end

#output_size_bytesObject

Returns the value of attribute output_size_bytes.



40
41
42
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 40

def output_size_bytes
  @output_size_bytes
end

#output_urlObject

Returns the value of attribute output_url.



38
39
40
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 38

def output_url
  @output_url
end

#outputsObject

Returns the value of attribute outputs.



50
51
52
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 50

def outputs
  @outputs
end

#progress_percentObject

Returns the value of attribute progress_percent.



44
45
46
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 44

def progress_percent
  @progress_percent
end

#project_idObject

Returns the value of attribute project_id.



22
23
24
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 22

def project_id
  @project_id
end

#projectsObject

Returns the value of attribute projects.



52
53
54
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 52

def projects
  @projects
end

#sprite_urlObject

Returns the value of attribute sprite_url.



46
47
48
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 46

def sprite_url
  @sprite_url
end

#stageObject

Returns the value of attribute stage.



26
27
28
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 26

def stage
  @stage
end

#statusObject

Returns the value of attribute status.



24
25
26
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 24

def status
  @status
end

#video_jsonObject

Returns the value of attribute video_json.



48
49
50
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 48

def video_json
  @video_json
end

#widthObject

Returns the value of attribute width.



32
33
34
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 32

def width
  @width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 59

def self.attribute_map
  {
    :'id' => :'id',
    :'job_id' => :'job_id',
    :'project_id' => :'project_id',
    :'status' => :'status',
    :'stage' => :'stage',
    :'cost' => :'cost',
    :'duration' => :'duration',
    :'width' => :'width',
    :'height' => :'height',
    :'fps' => :'fps',
    :'output_url' => :'output_url',
    :'output_size_bytes' => :'output_size_bytes',
    :'error' => :'error',
    :'progress_percent' => :'progress_percent',
    :'sprite_url' => :'sprite_url',
    :'video_json' => :'video_json',
    :'outputs' => :'outputs',
    :'projects' => :'projects',
    :'created_at' => :'created_at',
    :'completed_at' => :'completed_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 297

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 121

def self.openapi_nullable
  Set.new([
    :'job_id',
    :'project_id',
    :'cost',
    :'duration',
    :'width',
    :'height',
    :'fps',
    :'output_url',
    :'output_size_bytes',
    :'error',
    :'progress_percent',
    :'sprite_url',
    :'video_json',
    :'projects',
    :'completed_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 95

def self.openapi_types
  {
    :'id' => :'String',
    :'job_id' => :'String',
    :'project_id' => :'String',
    :'status' => :'String',
    :'stage' => :'String',
    :'cost' => :'Float',
    :'duration' => :'Float',
    :'width' => :'Integer',
    :'height' => :'Integer',
    :'fps' => :'Integer',
    :'output_url' => :'String',
    :'output_size_bytes' => :'Integer',
    :'error' => :'String',
    :'progress_percent' => :'Integer',
    :'sprite_url' => :'String',
    :'video_json' => :'Object',
    :'outputs' => :'Array<RenditionOutput>',
    :'projects' => :'Object',
    :'created_at' => :'Time',
    :'completed_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      job_id == o.job_id &&
      project_id == o.project_id &&
      status == o.status &&
      stage == o.stage &&
      cost == o.cost &&
      duration == o.duration &&
      width == o.width &&
      height == o.height &&
      fps == o.fps &&
      output_url == o.output_url &&
      output_size_bytes == o.output_size_bytes &&
      error == o.error &&
      progress_percent == o.progress_percent &&
      sprite_url == o.sprite_url &&
      video_json == o.video_json &&
      outputs == o.outputs &&
      projects == o.projects &&
      created_at == o.created_at &&
      completed_at == o.completed_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


284
285
286
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 284

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



290
291
292
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 290

def hash
  [id, job_id, project_id, status, stage, cost, duration, width, height, fps, output_url, output_size_bytes, error, progress_percent, sprite_url, video_json, outputs, projects, created_at, completed_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



242
243
244
245
246
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 242

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 319

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



250
251
252
253
# File 'lib/generated/ilovevideoeditor-sdk/models/rendition.rb', line 250

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end