Class: ILoveVideoEditor::Template

Inherits:
ApiModelBase show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/template.rb

Overview

Full template including its preset configuration or project builder metadata.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Template

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::Template` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::Template`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  else
    self.platform = nil
  end

  if attributes.key?(:'accent_color')
    self.accent_color = attributes[:'accent_color']
  else
    self.accent_color = nil
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  else
    self.icon = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = nil
  end

  if attributes.key?(:'tool_id')
    self.tool_id = attributes[:'tool_id']
  end

  if attributes.key?(:'variables_schema')
    if (value = attributes[:'variables_schema']).is_a?(Array)
      self.variables_schema = value
    end
  end
end

Instance Attribute Details

#accent_colorObject

Returns the value of attribute accent_color.



27
28
29
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 27

def accent_color
  @accent_color
end

#descriptionObject

Returns the value of attribute description.



23
24
25
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 23

def description
  @description
end

#iconObject

Returns the value of attribute icon.



29
30
31
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 29

def icon
  @icon
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 19

def id
  @id
end

#modeObject

Returns the value of attribute mode.



31
32
33
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 31

def mode
  @mode
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 21

def name
  @name
end

#platformObject

Returns the value of attribute platform.



25
26
27
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 25

def platform
  @platform
end

#tool_idObject

Returns the value of attribute tool_id.



33
34
35
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 33

def tool_id
  @tool_id
end

#variables_schemaObject

Returns the value of attribute variables_schema.



35
36
37
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 35

def variables_schema
  @variables_schema
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 60

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'platform' => :'platform',
    :'accent_color' => :'accentColor',
    :'icon' => :'icon',
    :'mode' => :'mode',
    :'tool_id' => :'toolId',
    :'variables_schema' => :'variablesSchema'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 314

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
105
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 100

def self.openapi_nullable
  Set.new([
    :'tool_id',
    :'variables_schema'
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 85

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'platform' => :'String',
    :'accent_color' => :'String',
    :'icon' => :'String',
    :'mode' => :'String',
    :'tool_id' => :'String',
    :'variables_schema' => :'Array<Hash<String, Object>>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 285

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      platform == o.platform &&
      accent_color == o.accent_color &&
      icon == o.icon &&
      mode == o.mode &&
      tool_id == o.tool_id &&
      variables_schema == o.variables_schema
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



307
308
309
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 307

def hash
  [id, name, description, platform, accent_color, icon, mode, tool_id, variables_schema].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  if @accent_color.nil?
    invalid_properties.push('invalid value for "accent_color", accent_color cannot be nil.')
  end

  if @icon.nil?
    invalid_properties.push('invalid value for "icon", icon cannot be nil.')
  end

  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @platform.nil?
  platform_validator = EnumAttributeValidator.new('String', ["youtube", "tiktok", "instagram", "general"])
  return false unless platform_validator.valid?(@platform)
  return false if @accent_color.nil?
  return false if @icon.nil?
  return false if @mode.nil?
  mode_validator = EnumAttributeValidator.new('String', ["preset", "project"])
  return false unless mode_validator.valid?(@mode)
  true
end