Class: ILoveVideoEditor::ToolJobStatus

Inherits:
ApiModelBase show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ToolJobStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::ToolJobStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::ToolJobStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'job_id')
    self.job_id = attributes[:'job_id']
  else
    self.job_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'stage')
    self.stage = attributes[:'stage']
  else
    self.stage = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'output_key')
    self.output_key = attributes[:'output_key']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  end

  if attributes.key?(:'outputs')
    if (value = attributes[:'outputs']).is_a?(Array)
      self.outputs = value
    end
  end
end

Instance Attribute Details

#errorObject

Returns the value of attribute error.



33
34
35
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 33

def error
  @error
end

#job_idObject

Returns the value of attribute job_id.



18
19
20
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 18

def job_id
  @job_id
end

#modeObject

Whether the job ran on the native ffmpeg worker or the render pipeline.



25
26
27
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 25

def mode
  @mode
end

#output_keyObject

Storage key of the output file when completed.



28
29
30
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 28

def output_key
  @output_key
end

#outputsObject

Per-destination outputs when external integrations were used.



38
39
40
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 38

def outputs
  @outputs
end

#progressObject

Returns the value of attribute progress.



35
36
37
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 35

def progress
  @progress
end

#stageObject

Returns the value of attribute stage.



22
23
24
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 22

def stage
  @stage
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 20

def status
  @status
end

#urlObject

Direct download URL when completed.



31
32
33
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 31

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 63

def self.attribute_map
  {
    :'job_id' => :'jobId',
    :'status' => :'status',
    :'stage' => :'stage',
    :'mode' => :'mode',
    :'output_key' => :'outputKey',
    :'url' => :'url',
    :'error' => :'error',
    :'progress' => :'progress',
    :'outputs' => :'outputs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 272

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 88

def self.openapi_types
  {
    :'job_id' => :'String',
    :'status' => :'String',
    :'stage' => :'String',
    :'mode' => :'String',
    :'output_key' => :'String',
    :'url' => :'String',
    :'error' => :'String',
    :'progress' => :'RenderJobProgress',
    :'outputs' => :'Array<RenditionOutput>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      job_id == o.job_id &&
      status == o.status &&
      stage == o.stage &&
      mode == o.mode &&
      output_key == o.output_key &&
      url == o.url &&
      error == o.error &&
      progress == o.progress &&
      outputs == o.outputs
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



265
266
267
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 265

def hash
  [job_id, status, stage, mode, output_key, url, error, progress, outputs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @job_id.nil?
    invalid_properties.push('invalid value for "job_id", job_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @stage.nil?
    invalid_properties.push('invalid value for "stage", stage cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
195
196
197
198
199
# File 'lib/generated/ilovevideoeditor-sdk/models/tool_job_status.rb', line 191

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @job_id.nil?
  return false if @status.nil?
  return false if @stage.nil?
  mode_validator = EnumAttributeValidator.new('String', ["native", "render", "unknown"])
  return false unless mode_validator.valid?(@mode)
  true
end