Class: ILoveVideoEditor::VideoJSON

Inherits:
ApiModelBase show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/video_json.rb

Overview

Portable video scene definition produced by @ilovevideoeditor/core. The first layer must be a composition layer containing project settings (width, height, fps, sourceDuration, …).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VideoJSON

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::VideoJSON` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::VideoJSON`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'layers')
    if (value = attributes[:'layers']).is_a?(Array)
      self.layers = value
    end
  else
    self.layers = nil
  end

  if attributes.key?(:'tracks')
    if (value = attributes[:'tracks']).is_a?(Array)
      self.tracks = value
    end
  end

  if attributes.key?(:'destinations')
    if (value = attributes[:'destinations']).is_a?(Array)
      self.destinations = value
    end
  end
end

Instance Attribute Details

#destinationsObject

Optional output destinations for this render. Each entry references a workspace integration by ID; the API resolves credentials server-side.



26
27
28
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 26

def destinations
  @destinations
end

#layersObject

Returns the value of attribute layers.



21
22
23
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 21

def layers
  @layers
end

#nameObject

Returns the value of attribute name.



19
20
21
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 19

def name
  @name
end

#tracksObject

Returns the value of attribute tracks.



23
24
25
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 23

def tracks
  @tracks
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



39
40
41
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 39

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 44

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 29

def self.attribute_map
  {
    :'name' => :'name',
    :'layers' => :'layers',
    :'tracks' => :'tracks',
    :'destinations' => :'destinations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 205

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 49

def self.openapi_types
  {
    :'name' => :'String',
    :'layers' => :'Array<Object>',
    :'tracks' => :'Array<Object>',
    :'destinations' => :'Array<VideoJSONDestination>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      layers == o.layers &&
      tracks == o.tracks &&
      destinations == o.destinations
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


192
193
194
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 192

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



198
199
200
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 198

def hash
  [name, layers, tracks, destinations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 200
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 200.')
  end

  if @layers.nil?
    invalid_properties.push('invalid value for "layers", layers cannot be nil.')
  end

  if @layers.length > 50
    invalid_properties.push('invalid value for "layers", number of items must be less than or equal to 50.')
  end

  if @layers.length < 1
    invalid_properties.push('invalid value for "layers", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 227

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
143
144
145
# File 'lib/generated/ilovevideoeditor-sdk/models/video_json.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 200
  return false if @layers.nil?
  return false if @layers.length > 50
  return false if @layers.length < 1
  true
end