Class: ILoveVideoEditor::Workflow
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::Workflow
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/workflow.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#definition ⇒ Object
Returns the value of attribute definition.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#name ⇒ Object
Returns the value of attribute name.
-
#source_preset_id ⇒ Object
Id of the system preset this workflow was imported from (null when built from scratch).
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Workflow
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Workflow
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::Workflow` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::Workflow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] else self.workspace_id = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'definition') self.definition = attributes[:'definition'] else self.definition = nil end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] else self.is_active = nil end if attributes.key?(:'source_preset_id') self.source_preset_id = attributes[:'source_preset_id'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
35 36 37 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 35 def created_at @created_at end |
#created_by ⇒ Object
Returns the value of attribute created_by.
22 23 24 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 22 def created_by @created_by end |
#definition ⇒ Object
Returns the value of attribute definition.
28 29 30 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 28 def definition @definition end |
#description ⇒ Object
Returns the value of attribute description.
26 27 28 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 26 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 18 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
30 31 32 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 30 def is_active @is_active end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 24 def name @name end |
#source_preset_id ⇒ Object
Id of the system preset this workflow was imported from (null when built from scratch).
33 34 35 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 33 def source_preset_id @source_preset_id end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
37 38 39 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 37 def updated_at @updated_at end |
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
20 21 22 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 20 def workspace_id @workspace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 40 def self.attribute_map { :'id' => :'id', :'workspace_id' => :'workspaceId', :'created_by' => :'createdBy', :'name' => :'name', :'description' => :'description', :'definition' => :'definition', :'is_active' => :'isActive', :'source_preset_id' => :'sourcePresetId', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 329 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 87 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 82 def self.openapi_nullable Set.new([ :'description', :'source_preset_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 66 def self.openapi_types { :'id' => :'String', :'workspace_id' => :'String', :'created_by' => :'String', :'name' => :'String', :'description' => :'String', :'definition' => :'WorkflowDefinition', :'is_active' => :'Boolean', :'source_preset_id' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 299 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && workspace_id == o.workspace_id && created_by == o.created_by && name == o.name && description == o.description && definition == o.definition && is_active == o.is_active && source_preset_id == o.source_preset_id && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
316 317 318 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 316 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
322 323 324 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 322 def hash [id, workspace_id, created_by, name, description, definition, is_active, source_preset_id, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @workspace_id.nil? invalid_properties.push('invalid value for "workspace_id", workspace_id cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @definition.nil? invalid_properties.push('invalid value for "definition", definition cannot be nil.') end if @is_active.nil? invalid_properties.push('invalid value for "is_active", is_active cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 351 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow.rb', line 204 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @workspace_id.nil? return false if @created_by.nil? return false if @name.nil? return false if @definition.nil? return false if @is_active.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |