Class: ILoveVideoEditor::WorkflowDefinition
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::WorkflowDefinition
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#steps ⇒ Object
Returns the value of attribute steps.
-
#variables ⇒ Object
Returns the value of attribute variables.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowDefinition
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowDefinition
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::WorkflowDefinition` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::WorkflowDefinition`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'variables') if (value = attributes[:'variables']).is_a?(Hash) self.variables = value end else self.variables = nil end if attributes.key?(:'steps') if (value = attributes[:'steps']).is_a?(Array) self.steps = value end else self.steps = nil end end |
Instance Attribute Details
#steps ⇒ Object
Returns the value of attribute steps.
22 23 24 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 22 def steps @steps end |
#variables ⇒ Object
Returns the value of attribute variables.
20 21 22 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 20 def variables @variables end |
#version ⇒ Object
Returns the value of attribute version.
18 19 20 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 18 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 47 def self.attribute_map { :'version' => :'version', :'variables' => :'variables', :'steps' => :'steps' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 224 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 66 def self.openapi_types { :'version' => :'Integer', :'variables' => :'Hash<String, WorkflowVariable>', :'steps' => :'Array<WorkflowStep>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
201 202 203 204 205 206 207 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 201 def ==(o) return true if self.equal?(o) self.class == o.class && version == o.version && variables == o.variables && steps == o.steps end |
#eql?(o) ⇒ Boolean
211 212 213 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 211 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 217 def hash [version, variables, steps].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @variables.nil? invalid_properties.push('invalid value for "variables", variables cannot be nil.') end if @steps.nil? invalid_properties.push('invalid value for "steps", steps cannot be nil.') end if @steps.length > 20 invalid_properties.push('invalid value for "steps", number of items must be less than or equal to 20.') end if @steps.length < 1 invalid_properties.push('invalid value for "steps", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_definition.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @version.nil? version_validator = EnumAttributeValidator.new('Integer', [1]) return false unless version_validator.valid?(@version) return false if @variables.nil? return false if @steps.nil? return false if @steps.length > 20 return false if @steps.length < 1 true end |