Class: ILoveVideoEditor::WorkflowPreset
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::WorkflowPreset
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#category ⇒ Object
Returns the value of attribute category.
-
#channels ⇒ Object
Onboarding channels this preset is recommended for.
-
#definition ⇒ Object
Returns the value of attribute definition.
-
#description ⇒ Object
Returns the value of attribute description.
-
#estimated_credits ⇒ Object
Approximate credits consumed per run.
-
#goals ⇒ Object
Onboarding goals this preset is recommended for.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#poster_template_id ⇒ Object
Toolkit template id whose poster image represents this preset.
-
#roles ⇒ Object
Onboarding roles this preset is recommended for.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowPreset
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowPreset
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::WorkflowPreset` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::WorkflowPreset`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'category') self.category = attributes[:'category'] else self.category = nil end if attributes.key?(:'roles') if (value = attributes[:'roles']).is_a?(Array) self.roles = value end else self.roles = nil end if attributes.key?(:'goals') if (value = attributes[:'goals']).is_a?(Array) self.goals = value end else self.goals = nil end if attributes.key?(:'channels') if (value = attributes[:'channels']).is_a?(Array) self.channels = value end else self.channels = nil end if attributes.key?(:'poster_template_id') self.poster_template_id = attributes[:'poster_template_id'] end if attributes.key?(:'estimated_credits') self.estimated_credits = attributes[:'estimated_credits'] else self.estimated_credits = nil end if attributes.key?(:'definition') self.definition = attributes[:'definition'] else self.definition = nil end end |
Instance Attribute Details
#category ⇒ Object
Returns the value of attribute category.
24 25 26 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 24 def category @category end |
#channels ⇒ Object
Onboarding channels this preset is recommended for.
33 34 35 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 33 def channels @channels end |
#definition ⇒ Object
Returns the value of attribute definition.
41 42 43 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 41 def definition @definition end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 22 def description @description end |
#estimated_credits ⇒ Object
Approximate credits consumed per run.
39 40 41 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 39 def estimated_credits @estimated_credits end |
#goals ⇒ Object
Onboarding goals this preset is recommended for.
30 31 32 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 30 def goals @goals end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 18 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 20 def name @name end |
#poster_template_id ⇒ Object
Toolkit template id whose poster image represents this preset.
36 37 38 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 36 def poster_template_id @poster_template_id end |
#roles ⇒ Object
Onboarding roles this preset is recommended for.
27 28 29 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 27 def roles @roles end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 66 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'category' => :'category', :'roles' => :'roles', :'goals' => :'goals', :'channels' => :'channels', :'poster_template_id' => :'posterTemplateId', :'estimated_credits' => :'estimatedCredits', :'definition' => :'definition' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 379 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 112 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 108 def self.openapi_nullable Set.new([ :'poster_template_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 92 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'category' => :'String', :'roles' => :'Array<String>', :'goals' => :'Array<String>', :'channels' => :'Array<String>', :'poster_template_id' => :'String', :'estimated_credits' => :'Integer', :'definition' => :'WorkflowDefinition' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 349 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && category == o.category && roles == o.roles && goals == o.goals && channels == o.channels && poster_template_id == o.poster_template_id && estimated_credits == o.estimated_credits && definition == o.definition end |
#eql?(o) ⇒ Boolean
366 367 368 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 366 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
372 373 374 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 372 def hash [id, name, description, category, roles, goals, channels, poster_template_id, estimated_credits, definition].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 197 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @category.nil? invalid_properties.push('invalid value for "category", category cannot be nil.') end if @roles.nil? invalid_properties.push('invalid value for "roles", roles cannot be nil.') end if @goals.nil? invalid_properties.push('invalid value for "goals", goals cannot be nil.') end if @channels.nil? invalid_properties.push('invalid value for "channels", channels cannot be nil.') end if @estimated_credits.nil? invalid_properties.push('invalid value for "estimated_credits", estimated_credits cannot be nil.') end if @definition.nil? invalid_properties.push('invalid value for "definition", definition cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 401 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_preset.rb', line 241 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @description.nil? return false if @category.nil? category_validator = EnumAttributeValidator.new('String', ["getting-started", "social", "promo", "real_estate", "travel", "events", "news", "beauty", "automotive", "business"]) return false unless category_validator.valid?(@category) return false if @roles.nil? return false if @goals.nil? return false if @channels.nil? return false if @estimated_credits.nil? return false if @definition.nil? true end |