Class: ILoveVideoEditor::WorkflowRunStep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::WorkflowRunStep
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb
Instance Attribute Summary collapse
-
#completed_at ⇒ Object
Returns the value of attribute completed_at.
-
#config ⇒ Object
Returns the value of attribute config.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#error ⇒ Object
Returns the value of attribute error.
-
#id ⇒ Object
Returns the value of attribute id.
-
#input_url ⇒ Object
Returns the value of attribute input_url.
-
#logs ⇒ Object
Returns the value of attribute logs.
-
#max_retries ⇒ Object
Returns the value of attribute max_retries.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#output_key ⇒ Object
Returns the value of attribute output_key.
-
#output_url ⇒ Object
Returns the value of attribute output_url.
-
#rendition_id ⇒ Object
Returns the value of attribute rendition_id.
-
#response_status ⇒ Object
Returns the value of attribute response_status.
-
#retry_count ⇒ Object
Returns the value of attribute retry_count.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#step_index ⇒ Object
Returns the value of attribute step_index.
-
#step_type ⇒ Object
Returns the value of attribute step_type.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#workflow_run_id ⇒ Object
Returns the value of attribute workflow_run_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowRunStep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowRunStep
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 144 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::WorkflowRunStep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::WorkflowRunStep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'workflow_run_id') self.workflow_run_id = attributes[:'workflow_run_id'] else self.workflow_run_id = nil end if attributes.key?(:'step_index') self.step_index = attributes[:'step_index'] else self.step_index = nil end if attributes.key?(:'step_type') self.step_type = attributes[:'step_type'] else self.step_type = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'config') self.config = attributes[:'config'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'input_url') self.input_url = attributes[:'input_url'] end if attributes.key?(:'output_url') self.output_url = attributes[:'output_url'] end if attributes.key?(:'output_key') self.output_key = attributes[:'output_key'] end if attributes.key?(:'rendition_id') self.rendition_id = attributes[:'rendition_id'] end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'response_status') self.response_status = attributes[:'response_status'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'retry_count') self.retry_count = attributes[:'retry_count'] end if attributes.key?(:'max_retries') self.max_retries = attributes[:'max_retries'] end if attributes.key?(:'logs') if (value = attributes[:'logs']).is_a?(Array) self.logs = value end end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#completed_at ⇒ Object
Returns the value of attribute completed_at.
54 55 56 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 54 def completed_at @completed_at end |
#config ⇒ Object
Returns the value of attribute config.
28 29 30 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 28 def config @config end |
#created_at ⇒ Object
Returns the value of attribute created_at.
56 57 58 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 56 def created_at @created_at end |
#error ⇒ Object
Returns the value of attribute error.
40 41 42 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 40 def error @error end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 18 def id @id end |
#input_url ⇒ Object
Returns the value of attribute input_url.
32 33 34 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 32 def input_url @input_url end |
#logs ⇒ Object
Returns the value of attribute logs.
50 51 52 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 50 def logs @logs end |
#max_retries ⇒ Object
Returns the value of attribute max_retries.
48 49 50 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 48 def max_retries @max_retries end |
#metadata ⇒ Object
Returns the value of attribute metadata.
44 45 46 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 44 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
26 27 28 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 26 def name @name end |
#output_key ⇒ Object
Returns the value of attribute output_key.
36 37 38 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 36 def output_key @output_key end |
#output_url ⇒ Object
Returns the value of attribute output_url.
34 35 36 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 34 def output_url @output_url end |
#rendition_id ⇒ Object
Returns the value of attribute rendition_id.
38 39 40 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 38 def rendition_id @rendition_id end |
#response_status ⇒ Object
Returns the value of attribute response_status.
42 43 44 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 42 def response_status @response_status end |
#retry_count ⇒ Object
Returns the value of attribute retry_count.
46 47 48 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 46 def retry_count @retry_count end |
#started_at ⇒ Object
Returns the value of attribute started_at.
52 53 54 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 52 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
30 31 32 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 30 def status @status end |
#step_index ⇒ Object
Returns the value of attribute step_index.
22 23 24 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 22 def step_index @step_index end |
#step_type ⇒ Object
Returns the value of attribute step_type.
24 25 26 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 24 def step_type @step_type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
58 59 60 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 58 def updated_at @updated_at end |
#workflow_run_id ⇒ Object
Returns the value of attribute workflow_run_id.
20 21 22 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 20 def workflow_run_id @workflow_run_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 61 def self.attribute_map { :'id' => :'id', :'workflow_run_id' => :'workflowRunId', :'step_index' => :'stepIndex', :'step_type' => :'stepType', :'name' => :'name', :'config' => :'config', :'status' => :'status', :'input_url' => :'inputUrl', :'output_url' => :'outputUrl', :'output_key' => :'outputKey', :'rendition_id' => :'renditionId', :'error' => :'error', :'response_status' => :'responseStatus', :'metadata' => :'metadata', :'retry_count' => :'retryCount', :'max_retries' => :'maxRetries', :'logs' => :'logs', :'started_at' => :'startedAt', :'completed_at' => :'completedAt', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 371 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 125 def self.openapi_nullable Set.new([ :'name', :'config', :'input_url', :'output_url', :'output_key', :'rendition_id', :'error', :'response_status', :'metadata', :'logs', :'started_at', :'completed_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 98 def self.openapi_types { :'id' => :'String', :'workflow_run_id' => :'String', :'step_index' => :'Integer', :'step_type' => :'String', :'name' => :'String', :'config' => :'Object', :'status' => :'String', :'input_url' => :'String', :'output_url' => :'String', :'output_key' => :'String', :'rendition_id' => :'String', :'error' => :'String', :'response_status' => :'Integer', :'metadata' => :'Object', :'retry_count' => :'Integer', :'max_retries' => :'Integer', :'logs' => :'Array<Object>', :'started_at' => :'Time', :'completed_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 330 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && workflow_run_id == o.workflow_run_id && step_index == o.step_index && step_type == o.step_type && name == o.name && config == o.config && status == o.status && input_url == o.input_url && output_url == o.output_url && output_key == o.output_key && rendition_id == o.rendition_id && error == o.error && response_status == o.response_status && == o. && retry_count == o.retry_count && max_retries == o.max_retries && logs == o.logs && started_at == o.started_at && completed_at == o.completed_at && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
358 359 360 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 358 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
364 365 366 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 364 def hash [id, workflow_run_id, step_index, step_type, name, config, status, input_url, output_url, output_key, rendition_id, error, response_status, , retry_count, max_retries, logs, started_at, completed_at, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 255 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @workflow_run_id.nil? invalid_properties.push('invalid value for "workflow_run_id", workflow_run_id cannot be nil.') end if @step_index.nil? invalid_properties.push('invalid value for "step_index", step_index cannot be nil.') end if @step_type.nil? invalid_properties.push('invalid value for "step_type", step_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 393 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
279 280 281 282 283 284 285 286 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run_step.rb', line 279 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @workflow_run_id.nil? return false if @step_index.nil? return false if @step_type.nil? true end |