Class: ILoveVideoEditor::WorkflowsApi
- Inherits:
-
Object
- Object
- ILoveVideoEditor::WorkflowsApi
- Defined in:
- lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel_workflow_run(run_id, opts = {}) ⇒ UploadAsset200Response
Cancel a workflow run.
-
#cancel_workflow_run_with_http_info(run_id, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Cancel a workflow run.
-
#create_workflow(create_workflow_request, opts = {}) ⇒ CreateWorkflow201Response
Create a workflow.
-
#create_workflow_with_http_info(create_workflow_request, opts = {}) ⇒ Array<(CreateWorkflow201Response, Integer, Hash)>
Create a workflow.
-
#delete_workflow(id, opts = {}) ⇒ UploadAsset200Response
Delete a workflow.
-
#delete_workflow_with_http_info(id, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Delete a workflow.
-
#get_workflow(id, opts = {}) ⇒ GetWorkflow200Response
Get a workflow.
-
#get_workflow_preset(id, opts = {}) ⇒ GetWorkflowPreset200Response
Get a workflow preset.
-
#get_workflow_preset_with_http_info(id, opts = {}) ⇒ Array<(GetWorkflowPreset200Response, Integer, Hash)>
Get a workflow preset.
-
#get_workflow_run(run_id, opts = {}) ⇒ GetWorkflowRun200Response
Get a workflow run.
-
#get_workflow_run_with_http_info(run_id, opts = {}) ⇒ Array<(GetWorkflowRun200Response, Integer, Hash)>
Get a workflow run.
-
#get_workflow_with_http_info(id, opts = {}) ⇒ Array<(GetWorkflow200Response, Integer, Hash)>
Get a workflow.
-
#initialize(api_client = ApiClient.default) ⇒ WorkflowsApi
constructor
A new instance of WorkflowsApi.
-
#list_workflow_presets(opts = {}) ⇒ ListWorkflowPresets200Response
List system workflow presets Returns the code-side catalog of ready-made workflow presets ("Browse workflows").
-
#list_workflow_presets_with_http_info(opts = {}) ⇒ Array<(ListWorkflowPresets200Response, Integer, Hash)>
List system workflow presets Returns the code-side catalog of ready-made workflow presets ("Browse workflows").
-
#list_workflow_runs(id, opts = {}) ⇒ ListWorkflowRuns200Response
List workflow runs.
-
#list_workflow_runs_with_http_info(id, opts = {}) ⇒ Array<(ListWorkflowRuns200Response, Integer, Hash)>
List workflow runs.
-
#list_workflow_step_types(opts = {}) ⇒ ListWorkflowStepTypes200Response
List available workflow step types.
-
#list_workflow_step_types_with_http_info(opts = {}) ⇒ Array<(ListWorkflowStepTypes200Response, Integer, Hash)>
List available workflow step types.
-
#list_workflows(opts = {}) ⇒ ListWorkflows200Response
List workflows.
-
#list_workflows_with_http_info(opts = {}) ⇒ Array<(ListWorkflows200Response, Integer, Hash)>
List workflows.
-
#retry_workflow_run(run_id, opts = {}) ⇒ RunWorkflow202Response
Retry a workflow run.
-
#retry_workflow_run_with_http_info(run_id, opts = {}) ⇒ Array<(RunWorkflow202Response, Integer, Hash)>
Retry a workflow run.
-
#retry_workflow_step(run_id, step_id, opts = {}) ⇒ UploadAsset200Response
Retry a workflow step.
-
#retry_workflow_step_with_http_info(run_id, step_id, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Retry a workflow step.
-
#review_workflow_step(run_id, step_id, review_workflow_step_request, opts = {}) ⇒ UploadAsset200Response
Approve or reject a paused review step Resolves a human-in-the-loop
reviewstep that is waiting for input (the run is inwaiting_reviewstatus). -
#review_workflow_step_with_http_info(run_id, step_id, review_workflow_step_request, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Approve or reject a paused review step Resolves a human-in-the-loop `review` step that is waiting for input (the run is in `waiting_review` status).
-
#run_workflow(id, run_workflow_request, opts = {}) ⇒ RunWorkflow202Response
Run a workflow.
-
#run_workflow_with_http_info(id, run_workflow_request, opts = {}) ⇒ Array<(RunWorkflow202Response, Integer, Hash)>
Run a workflow.
-
#skip_workflow_step(run_id, step_id, opts = {}) ⇒ UploadAsset200Response
Skip a workflow step.
-
#skip_workflow_step_with_http_info(run_id, step_id, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Skip a workflow step.
-
#update_workflow(id, update_workflow_request, opts = {}) ⇒ CreateWorkflow201Response
Update a workflow.
-
#update_workflow_with_http_info(id, update_workflow_request, opts = {}) ⇒ Array<(CreateWorkflow201Response, Integer, Hash)>
Update a workflow.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WorkflowsApi
Returns a new instance of WorkflowsApi.
19 20 21 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cancel_workflow_run(run_id, opts = {}) ⇒ UploadAsset200Response
Cancel a workflow run
26 27 28 29 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 26 def cancel_workflow_run(run_id, opts = {}) data, _status_code, _headers = cancel_workflow_run_with_http_info(run_id, opts) data end |
#cancel_workflow_run_with_http_info(run_id, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Cancel a workflow run
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 35 def cancel_workflow_run_with_http_info(run_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.cancel_workflow_run ...' end # verify the required parameter 'run_id' is set if @api_client.config.client_side_validation && run_id.nil? fail ArgumentError, "Missing the required parameter 'run_id' when calling WorkflowsApi.cancel_workflow_run" end # resource path local_var_path = '/v1/workflows/runs/{runId}/cancel'.sub('{runId}', CGI.escape(run_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UploadAsset200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.cancel_workflow_run", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#cancel_workflow_run\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_workflow(create_workflow_request, opts = {}) ⇒ CreateWorkflow201Response
Create a workflow
87 88 89 90 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 87 def create_workflow(create_workflow_request, opts = {}) data, _status_code, _headers = create_workflow_with_http_info(create_workflow_request, opts) data end |
#create_workflow_with_http_info(create_workflow_request, opts = {}) ⇒ Array<(CreateWorkflow201Response, Integer, Hash)>
Create a workflow
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 96 def create_workflow_with_http_info(create_workflow_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.create_workflow ...' end # verify the required parameter 'create_workflow_request' is set if @api_client.config.client_side_validation && create_workflow_request.nil? fail ArgumentError, "Missing the required parameter 'create_workflow_request' when calling WorkflowsApi.create_workflow" end # resource path local_var_path = '/v1/workflows' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_workflow_request) # return_type return_type = opts[:debug_return_type] || 'CreateWorkflow201Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.create_workflow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#create_workflow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_workflow(id, opts = {}) ⇒ UploadAsset200Response
Delete a workflow
153 154 155 156 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 153 def delete_workflow(id, opts = {}) data, _status_code, _headers = delete_workflow_with_http_info(id, opts) data end |
#delete_workflow_with_http_info(id, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Delete a workflow
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 162 def delete_workflow_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.delete_workflow ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WorkflowsApi.delete_workflow" end # resource path local_var_path = '/v1/workflows/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UploadAsset200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.delete_workflow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#delete_workflow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_workflow(id, opts = {}) ⇒ GetWorkflow200Response
Get a workflow
214 215 216 217 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 214 def get_workflow(id, opts = {}) data, _status_code, _headers = get_workflow_with_http_info(id, opts) data end |
#get_workflow_preset(id, opts = {}) ⇒ GetWorkflowPreset200Response
Get a workflow preset
275 276 277 278 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 275 def get_workflow_preset(id, opts = {}) data, _status_code, _headers = get_workflow_preset_with_http_info(id, opts) data end |
#get_workflow_preset_with_http_info(id, opts = {}) ⇒ Array<(GetWorkflowPreset200Response, Integer, Hash)>
Get a workflow preset
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 284 def get_workflow_preset_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.get_workflow_preset ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WorkflowsApi.get_workflow_preset" end # resource path local_var_path = '/v1/workflows/presets/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWorkflowPreset200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.get_workflow_preset", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#get_workflow_preset\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_workflow_run(run_id, opts = {}) ⇒ GetWorkflowRun200Response
Get a workflow run
336 337 338 339 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 336 def get_workflow_run(run_id, opts = {}) data, _status_code, _headers = get_workflow_run_with_http_info(run_id, opts) data end |
#get_workflow_run_with_http_info(run_id, opts = {}) ⇒ Array<(GetWorkflowRun200Response, Integer, Hash)>
Get a workflow run
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 345 def get_workflow_run_with_http_info(run_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.get_workflow_run ...' end # verify the required parameter 'run_id' is set if @api_client.config.client_side_validation && run_id.nil? fail ArgumentError, "Missing the required parameter 'run_id' when calling WorkflowsApi.get_workflow_run" end # resource path local_var_path = '/v1/workflows/runs/{runId}'.sub('{runId}', CGI.escape(run_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWorkflowRun200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.get_workflow_run", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#get_workflow_run\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_workflow_with_http_info(id, opts = {}) ⇒ Array<(GetWorkflow200Response, Integer, Hash)>
Get a workflow
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 223 def get_workflow_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.get_workflow ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WorkflowsApi.get_workflow" end # resource path local_var_path = '/v1/workflows/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWorkflow200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.get_workflow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#get_workflow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_workflow_presets(opts = {}) ⇒ ListWorkflowPresets200Response
List system workflow presets Returns the code-side catalog of ready-made workflow presets ("Browse workflows"). Import one by POSTing its definition to /v1/workflows with sourcePresetId set to the preset id.
397 398 399 400 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 397 def list_workflow_presets(opts = {}) data, _status_code, _headers = list_workflow_presets_with_http_info(opts) data end |
#list_workflow_presets_with_http_info(opts = {}) ⇒ Array<(ListWorkflowPresets200Response, Integer, Hash)>
List system workflow presets Returns the code-side catalog of ready-made workflow presets ("Browse workflows"). Import one by POSTing its definition to /v1/workflows with sourcePresetId set to the preset id.
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 406 def list_workflow_presets_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.list_workflow_presets ...' end # resource path local_var_path = '/v1/workflows/presets' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListWorkflowPresets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.list_workflow_presets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#list_workflow_presets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_workflow_runs(id, opts = {}) ⇒ ListWorkflowRuns200Response
List workflow runs
456 457 458 459 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 456 def list_workflow_runs(id, opts = {}) data, _status_code, _headers = list_workflow_runs_with_http_info(id, opts) data end |
#list_workflow_runs_with_http_info(id, opts = {}) ⇒ Array<(ListWorkflowRuns200Response, Integer, Hash)>
List workflow runs
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 467 def list_workflow_runs_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.list_workflow_runs ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WorkflowsApi.list_workflow_runs" end # resource path local_var_path = '/v1/workflows/{id}/runs'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListWorkflowRuns200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.list_workflow_runs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#list_workflow_runs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_workflow_step_types(opts = {}) ⇒ ListWorkflowStepTypes200Response
List available workflow step types
520 521 522 523 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 520 def list_workflow_step_types(opts = {}) data, _status_code, _headers = list_workflow_step_types_with_http_info(opts) data end |
#list_workflow_step_types_with_http_info(opts = {}) ⇒ Array<(ListWorkflowStepTypes200Response, Integer, Hash)>
List available workflow step types
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 528 def list_workflow_step_types_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.list_workflow_step_types ...' end # resource path local_var_path = '/v1/workflows/step-types' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListWorkflowStepTypes200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.list_workflow_step_types", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#list_workflow_step_types\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_workflows(opts = {}) ⇒ ListWorkflows200Response
List workflows
577 578 579 580 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 577 def list_workflows(opts = {}) data, _status_code, _headers = list_workflows_with_http_info(opts) data end |
#list_workflows_with_http_info(opts = {}) ⇒ Array<(ListWorkflows200Response, Integer, Hash)>
List workflows
587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 587 def list_workflows_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.list_workflows ...' end # resource path local_var_path = '/v1/workflows' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListWorkflows200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.list_workflows", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#list_workflows\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retry_workflow_run(run_id, opts = {}) ⇒ RunWorkflow202Response
Retry a workflow run
637 638 639 640 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 637 def retry_workflow_run(run_id, opts = {}) data, _status_code, _headers = retry_workflow_run_with_http_info(run_id, opts) data end |
#retry_workflow_run_with_http_info(run_id, opts = {}) ⇒ Array<(RunWorkflow202Response, Integer, Hash)>
Retry a workflow run
646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 646 def retry_workflow_run_with_http_info(run_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.retry_workflow_run ...' end # verify the required parameter 'run_id' is set if @api_client.config.client_side_validation && run_id.nil? fail ArgumentError, "Missing the required parameter 'run_id' when calling WorkflowsApi.retry_workflow_run" end # resource path local_var_path = '/v1/workflows/runs/{runId}/retry'.sub('{runId}', CGI.escape(run_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RunWorkflow202Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.retry_workflow_run", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#retry_workflow_run\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retry_workflow_step(run_id, step_id, opts = {}) ⇒ UploadAsset200Response
Retry a workflow step
699 700 701 702 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 699 def retry_workflow_step(run_id, step_id, opts = {}) data, _status_code, _headers = retry_workflow_step_with_http_info(run_id, step_id, opts) data end |
#retry_workflow_step_with_http_info(run_id, step_id, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Retry a workflow step
709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 709 def retry_workflow_step_with_http_info(run_id, step_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.retry_workflow_step ...' end # verify the required parameter 'run_id' is set if @api_client.config.client_side_validation && run_id.nil? fail ArgumentError, "Missing the required parameter 'run_id' when calling WorkflowsApi.retry_workflow_step" end # verify the required parameter 'step_id' is set if @api_client.config.client_side_validation && step_id.nil? fail ArgumentError, "Missing the required parameter 'step_id' when calling WorkflowsApi.retry_workflow_step" end # resource path local_var_path = '/v1/workflows/runs/{runId}/steps/{stepId}/retry'.sub('{runId}', CGI.escape(run_id.to_s)).sub('{stepId}', CGI.escape(step_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UploadAsset200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.retry_workflow_step", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#retry_workflow_step\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#review_workflow_step(run_id, step_id, review_workflow_step_request, opts = {}) ⇒ UploadAsset200Response
Approve or reject a paused review step
Resolves a human-in-the-loop review step that is waiting for input (the run is in waiting_review status). Approving resumes the run; rejecting cancels it. Optionally edits run variables before resuming — only keys listed in the step's editableVariables are accepted.
768 769 770 771 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 768 def review_workflow_step(run_id, step_id, review_workflow_step_request, opts = {}) data, _status_code, _headers = review_workflow_step_with_http_info(run_id, step_id, review_workflow_step_request, opts) data end |
#review_workflow_step_with_http_info(run_id, step_id, review_workflow_step_request, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Approve or reject a paused review step Resolves a human-in-the-loop `review` step that is waiting for input (the run is in `waiting_review` status). Approving resumes the run; rejecting cancels it. Optionally edits run variables before resuming — only keys listed in the step's `editableVariables` are accepted.
780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 780 def review_workflow_step_with_http_info(run_id, step_id, review_workflow_step_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.review_workflow_step ...' end # verify the required parameter 'run_id' is set if @api_client.config.client_side_validation && run_id.nil? fail ArgumentError, "Missing the required parameter 'run_id' when calling WorkflowsApi.review_workflow_step" end # verify the required parameter 'step_id' is set if @api_client.config.client_side_validation && step_id.nil? fail ArgumentError, "Missing the required parameter 'step_id' when calling WorkflowsApi.review_workflow_step" end # verify the required parameter 'review_workflow_step_request' is set if @api_client.config.client_side_validation && review_workflow_step_request.nil? fail ArgumentError, "Missing the required parameter 'review_workflow_step_request' when calling WorkflowsApi.review_workflow_step" end # resource path local_var_path = '/v1/workflows/runs/{runId}/steps/{stepId}/review'.sub('{runId}', CGI.escape(run_id.to_s)).sub('{stepId}', CGI.escape(step_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(review_workflow_step_request) # return_type return_type = opts[:debug_return_type] || 'UploadAsset200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.review_workflow_step", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#review_workflow_step\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#run_workflow(id, run_workflow_request, opts = {}) ⇒ RunWorkflow202Response
Run a workflow
846 847 848 849 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 846 def run_workflow(id, run_workflow_request, opts = {}) data, _status_code, _headers = run_workflow_with_http_info(id, run_workflow_request, opts) data end |
#run_workflow_with_http_info(id, run_workflow_request, opts = {}) ⇒ Array<(RunWorkflow202Response, Integer, Hash)>
Run a workflow
856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 856 def run_workflow_with_http_info(id, run_workflow_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.run_workflow ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WorkflowsApi.run_workflow" end # verify the required parameter 'run_workflow_request' is set if @api_client.config.client_side_validation && run_workflow_request.nil? fail ArgumentError, "Missing the required parameter 'run_workflow_request' when calling WorkflowsApi.run_workflow" end # resource path local_var_path = '/v1/workflows/{id}/run'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(run_workflow_request) # return_type return_type = opts[:debug_return_type] || 'RunWorkflow202Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.run_workflow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#run_workflow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#skip_workflow_step(run_id, step_id, opts = {}) ⇒ UploadAsset200Response
Skip a workflow step
918 919 920 921 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 918 def skip_workflow_step(run_id, step_id, opts = {}) data, _status_code, _headers = skip_workflow_step_with_http_info(run_id, step_id, opts) data end |
#skip_workflow_step_with_http_info(run_id, step_id, opts = {}) ⇒ Array<(UploadAsset200Response, Integer, Hash)>
Skip a workflow step
928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 928 def skip_workflow_step_with_http_info(run_id, step_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.skip_workflow_step ...' end # verify the required parameter 'run_id' is set if @api_client.config.client_side_validation && run_id.nil? fail ArgumentError, "Missing the required parameter 'run_id' when calling WorkflowsApi.skip_workflow_step" end # verify the required parameter 'step_id' is set if @api_client.config.client_side_validation && step_id.nil? fail ArgumentError, "Missing the required parameter 'step_id' when calling WorkflowsApi.skip_workflow_step" end # resource path local_var_path = '/v1/workflows/runs/{runId}/steps/{stepId}/skip'.sub('{runId}', CGI.escape(run_id.to_s)).sub('{stepId}', CGI.escape(step_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UploadAsset200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.skip_workflow_step", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#skip_workflow_step\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_workflow(id, update_workflow_request, opts = {}) ⇒ CreateWorkflow201Response
Update a workflow
985 986 987 988 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 985 def update_workflow(id, update_workflow_request, opts = {}) data, _status_code, _headers = update_workflow_with_http_info(id, update_workflow_request, opts) data end |
#update_workflow_with_http_info(id, update_workflow_request, opts = {}) ⇒ Array<(CreateWorkflow201Response, Integer, Hash)>
Update a workflow
995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 |
# File 'lib/generated/ilovevideoeditor-sdk/api/workflows_api.rb', line 995 def update_workflow_with_http_info(id, update_workflow_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowsApi.update_workflow ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WorkflowsApi.update_workflow" end # verify the required parameter 'update_workflow_request' is set if @api_client.config.client_side_validation && update_workflow_request.nil? fail ArgumentError, "Missing the required parameter 'update_workflow_request' when calling WorkflowsApi.update_workflow" end # resource path local_var_path = '/v1/workflows/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_workflow_request) # return_type return_type = opts[:debug_return_type] || 'CreateWorkflow201Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"WorkflowsApi.update_workflow", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowsApi#update_workflow\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |