Class: ILoveVideoEditor::WorkspaceIntegration

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WorkspaceIntegration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::WorkspaceIntegration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::WorkspaceIntegration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  else
    self.workspace_id = nil
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  else
    self.is_active = nil
  end

  if attributes.key?(:'is_default')
    self.is_default = attributes[:'is_default']
  else
    self.is_default = nil
  end

  if attributes.key?(:'config')
    if (value = attributes[:'config']).is_a?(Hash)
      self.config = value
    end
  else
    self.config = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#configObject

Returns the value of attribute config.



30
31
32
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 30

def config
  @config
end

#created_atObject

Returns the value of attribute created_at.



32
33
34
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 32

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 18

def id
  @id
end

#is_activeObject

Returns the value of attribute is_active.



26
27
28
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 26

def is_active
  @is_active
end

#is_defaultObject

Returns the value of attribute is_default.



28
29
30
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 28

def is_default
  @is_default
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 24

def name
  @name
end

#providerObject

Returns the value of attribute provider.



22
23
24
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 22

def provider
  @provider
end

#updated_atObject

Returns the value of attribute updated_at.



34
35
36
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 34

def updated_at
  @updated_at
end

#workspace_idObject

Returns the value of attribute workspace_id.



20
21
22
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 20

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 59

def self.attribute_map
  {
    :'id' => :'id',
    :'workspace_id' => :'workspaceId',
    :'provider' => :'provider',
    :'name' => :'name',
    :'is_active' => :'isActive',
    :'is_default' => :'isDefault',
    :'config' => :'config',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 360

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 84

def self.openapi_types
  {
    :'id' => :'String',
    :'workspace_id' => :'String',
    :'provider' => :'String',
    :'name' => :'String',
    :'is_active' => :'Boolean',
    :'is_default' => :'Boolean',
    :'config' => :'Hash<String, Object>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 331

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      workspace_id == o.workspace_id &&
      provider == o.provider &&
      name == o.name &&
      is_active == o.is_active &&
      is_default == o.is_default &&
      config == o.config &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


347
348
349
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 347

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



353
354
355
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 353

def hash
  [id, workspace_id, provider, name, is_active, is_default, config, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @workspace_id.nil?
    invalid_properties.push('invalid value for "workspace_id", workspace_id cannot be nil.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @is_active.nil?
    invalid_properties.push('invalid value for "is_active", is_active cannot be nil.')
  end

  if @is_default.nil?
    invalid_properties.push('invalid value for "is_default", is_default cannot be nil.')
  end

  if @config.nil?
    invalid_properties.push('invalid value for "config", config cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/generated/ilovevideoeditor-sdk/models/workspace_integration.rb', line 223

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @workspace_id.nil?
  return false if @provider.nil?
  provider_validator = EnumAttributeValidator.new('String', ["s3", "r2", "b2", "wasabi", "gcs", "azure", "drive"])
  return false unless provider_validator.valid?(@provider)
  return false if @name.nil?
  return false if @is_active.nil?
  return false if @is_default.nil?
  return false if @config.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end