Class: ILoveVideoEditor::Asset
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::Asset
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/asset.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#asset_url ⇒ Object
Public Bunny CDN URL for the asset.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#duration ⇒ Object
Returns the value of attribute duration.
-
#height ⇒ Object
Returns the value of attribute height.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#size_bytes ⇒ Object
Returns the value of attribute size_bytes.
-
#storage_key ⇒ Object
Bunny Storage path.
-
#type ⇒ Object
Returns the value of attribute type.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#width ⇒ Object
Returns the value of attribute width.
-
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Asset
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Asset
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::Asset` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::Asset`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] else self.workspace_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'storage_key') self.storage_key = attributes[:'storage_key'] else self.storage_key = nil end if attributes.key?(:'asset_url') self.asset_url = attributes[:'asset_url'] end if attributes.key?(:'size_bytes') self.size_bytes = attributes[:'size_bytes'] else self.size_bytes = nil end if attributes.key?(:'duration') self.duration = attributes[:'duration'] end if attributes.key?(:'width') self.width = attributes[:'width'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#asset_url ⇒ Object
Public Bunny CDN URL for the asset.
30 31 32 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 30 def asset_url @asset_url end |
#created_at ⇒ Object
Returns the value of attribute created_at.
42 43 44 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 42 def created_at @created_at end |
#created_by ⇒ Object
Returns the value of attribute created_by.
40 41 42 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 40 def created_by @created_by end |
#duration ⇒ Object
Returns the value of attribute duration.
34 35 36 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 34 def duration @duration end |
#height ⇒ Object
Returns the value of attribute height.
38 39 40 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 38 def height @height end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 18 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 22 def name @name end |
#size_bytes ⇒ Object
Returns the value of attribute size_bytes.
32 33 34 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 32 def size_bytes @size_bytes end |
#storage_key ⇒ Object
Bunny Storage path.
27 28 29 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 27 def storage_key @storage_key end |
#type ⇒ Object
Returns the value of attribute type.
24 25 26 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 24 def type @type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
44 45 46 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 44 def updated_at @updated_at end |
#width ⇒ Object
Returns the value of attribute width.
36 37 38 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 36 def width @width end |
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
20 21 22 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 20 def workspace_id @workspace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 69 def self.attribute_map { :'id' => :'id', :'workspace_id' => :'workspace_id', :'name' => :'name', :'type' => :'type', :'storage_key' => :'storage_key', :'asset_url' => :'asset_url', :'size_bytes' => :'size_bytes', :'duration' => :'duration', :'width' => :'width', :'height' => :'height', :'created_by' => :'created_by', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 366 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
117 118 119 120 121 122 123 124 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 117 def self.openapi_nullable Set.new([ :'duration', :'width', :'height', :'created_by', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 98 def self.openapi_types { :'id' => :'String', :'workspace_id' => :'String', :'name' => :'String', :'type' => :'String', :'storage_key' => :'String', :'asset_url' => :'String', :'size_bytes' => :'Integer', :'duration' => :'Integer', :'width' => :'Integer', :'height' => :'Integer', :'created_by' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 333 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && workspace_id == o.workspace_id && name == o.name && type == o.type && storage_key == o.storage_key && asset_url == o.asset_url && size_bytes == o.size_bytes && duration == o.duration && width == o.width && height == o.height && created_by == o.created_by && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
353 354 355 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 353 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
359 360 361 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 359 def hash [id, workspace_id, name, type, storage_key, asset_url, size_bytes, duration, width, height, created_by, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 211 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @workspace_id.nil? invalid_properties.push('invalid value for "workspace_id", workspace_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @storage_key.nil? invalid_properties.push('invalid value for "storage_key", storage_key cannot be nil.') end if @size_bytes.nil? invalid_properties.push('invalid value for "size_bytes", size_bytes cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 388 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/generated/ilovevideoeditor-sdk/models/asset.rb', line 247 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @workspace_id.nil? return false if @name.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["image", "video", "audio", "font"]) return false unless type_validator.valid?(@type) return false if @storage_key.nil? return false if @size_bytes.nil? return false if @created_at.nil? true end |