Class: ILoveVideoEditor::Destination
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::Destination
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/destination.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_key_id ⇒ Object
Returns the value of attribute access_key_id.
-
#bucket ⇒ Object
Returns the value of attribute bucket.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#id ⇒ Object
Returns the value of attribute id.
-
#path_prefix ⇒ Object
Returns the value of attribute path_prefix.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#public_url ⇒ Object
Returns the value of attribute public_url.
-
#region ⇒ Object
Returns the value of attribute region.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Destination
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Destination
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::Destination` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::Destination`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'endpoint') self.endpoint = attributes[:'endpoint'] end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'bucket') self.bucket = attributes[:'bucket'] else self.bucket = nil end if attributes.key?(:'access_key_id') self.access_key_id = attributes[:'access_key_id'] else self.access_key_id = nil end if attributes.key?(:'secret_access_key') self.secret_access_key = attributes[:'secret_access_key'] else self.secret_access_key = nil end if attributes.key?(:'public_url') self.public_url = attributes[:'public_url'] end if attributes.key?(:'path_prefix') self.path_prefix = attributes[:'path_prefix'] end end |
Instance Attribute Details
#access_key_id ⇒ Object
Returns the value of attribute access_key_id.
28 29 30 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 28 def access_key_id @access_key_id end |
#bucket ⇒ Object
Returns the value of attribute bucket.
26 27 28 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 26 def bucket @bucket end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
22 23 24 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 22 def endpoint @endpoint end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 18 def id @id end |
#path_prefix ⇒ Object
Returns the value of attribute path_prefix.
34 35 36 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 34 def path_prefix @path_prefix end |
#provider ⇒ Object
Returns the value of attribute provider.
20 21 22 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 20 def provider @provider end |
#public_url ⇒ Object
Returns the value of attribute public_url.
32 33 34 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 32 def public_url @public_url end |
#region ⇒ Object
Returns the value of attribute region.
24 25 26 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 24 def region @region end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
30 31 32 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 30 def secret_access_key @secret_access_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 59 def self.attribute_map { :'id' => :'id', :'provider' => :'provider', :'endpoint' => :'endpoint', :'region' => :'region', :'bucket' => :'bucket', :'access_key_id' => :'accessKeyId', :'secret_access_key' => :'secretAccessKey', :'public_url' => :'publicUrl', :'path_prefix' => :'pathPrefix' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 293 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 104 105 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 99 def self.openapi_nullable Set.new([ :'endpoint', :'region', :'public_url', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 84 def self.openapi_types { :'id' => :'String', :'provider' => :'String', :'endpoint' => :'String', :'region' => :'String', :'bucket' => :'String', :'access_key_id' => :'String', :'secret_access_key' => :'String', :'public_url' => :'String', :'path_prefix' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 264 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && provider == o.provider && endpoint == o.endpoint && region == o.region && bucket == o.bucket && access_key_id == o.access_key_id && secret_access_key == o.secret_access_key && public_url == o.public_url && path_prefix == o.path_prefix end |
#eql?(o) ⇒ Boolean
280 281 282 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 280 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
286 287 288 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 286 def hash [id, provider, endpoint, region, bucket, access_key_id, secret_access_key, public_url, path_prefix].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 172 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if @bucket.nil? invalid_properties.push('invalid value for "bucket", bucket cannot be nil.') end if @access_key_id.nil? invalid_properties.push('invalid value for "access_key_id", access_key_id cannot be nil.') end if @secret_access_key.nil? invalid_properties.push('invalid value for "secret_access_key", secret_access_key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 315 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/generated/ilovevideoeditor-sdk/models/destination.rb', line 200 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @provider.nil? provider_validator = EnumAttributeValidator.new('String', ["s3", "r2", "b2", "wasabi"]) return false unless provider_validator.valid?(@provider) return false if @bucket.nil? return false if @access_key_id.nil? return false if @secret_access_key.nil? true end |