Class: ILoveVideoEditor::RenderJob
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::RenderJob
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/render_job.rb
Instance Attribute Summary collapse
-
#completed_at ⇒ Object
Returns the value of attribute completed_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#error ⇒ Object
Returns the value of attribute error.
-
#job_id ⇒ Object
Returns the value of attribute job_id.
-
#output_key ⇒ Object
Storage key of the output file when completed.
-
#outputs ⇒ Object
Per-destination outputs when external integrations were used.
-
#progress ⇒ Object
Returns the value of attribute progress.
-
#stage ⇒ Object
Granular pipeline stage.
-
#status ⇒ Object
Returns the value of attribute status.
-
#url ⇒ Object
Absolute signed download URL when completed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RenderJob
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RenderJob
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::RenderJob` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::RenderJob`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'job_id') self.job_id = attributes[:'job_id'] else self.job_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'stage') self.stage = attributes[:'stage'] end if attributes.key?(:'output_key') self.output_key = attributes[:'output_key'] end if attributes.key?(:'progress') self.progress = attributes[:'progress'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'outputs') if (value = attributes[:'outputs']).is_a?(Array) self.outputs = value end end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end end |
Instance Attribute Details
#completed_at ⇒ Object
Returns the value of attribute completed_at.
40 41 42 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 40 def completed_at @completed_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
38 39 40 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 38 def created_at @created_at end |
#error ⇒ Object
Returns the value of attribute error.
36 37 38 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 36 def error @error end |
#job_id ⇒ Object
Returns the value of attribute job_id.
18 19 20 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 18 def job_id @job_id end |
#output_key ⇒ Object
Storage key of the output file when completed.
26 27 28 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 26 def output_key @output_key end |
#outputs ⇒ Object
Per-destination outputs when external integrations were used.
34 35 36 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 34 def outputs @outputs end |
#progress ⇒ Object
Returns the value of attribute progress.
28 29 30 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 28 def progress @progress end |
#stage ⇒ Object
Granular pipeline stage.
23 24 25 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 23 def stage @stage end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 20 def status @status end |
#url ⇒ Object
Absolute signed download URL when completed.
31 32 33 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 31 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 43 def self.attribute_map { :'job_id' => :'jobId', :'status' => :'status', :'stage' => :'stage', :'output_key' => :'outputKey', :'progress' => :'progress', :'url' => :'url', :'outputs' => :'outputs', :'error' => :'error', :'created_at' => :'createdAt', :'completed_at' => :'completedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 233 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 89 90 91 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 85 def self.openapi_nullable Set.new([ :'url', :'error', :'completed_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 69 def self.openapi_types { :'job_id' => :'String', :'status' => :'String', :'stage' => :'String', :'output_key' => :'String', :'progress' => :'RenderJobProgress', :'url' => :'String', :'outputs' => :'Array<RenditionOutput>', :'error' => :'String', :'created_at' => :'Time', :'completed_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && job_id == o.job_id && status == o.status && stage == o.stage && output_key == o.output_key && progress == o.progress && url == o.url && outputs == o.outputs && error == o.error && created_at == o.created_at && completed_at == o.completed_at end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 226 def hash [job_id, status, stage, output_key, progress, url, outputs, error, created_at, completed_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 158 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @job_id.nil? invalid_properties.push('invalid value for "job_id", job_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 |
# File 'lib/generated/ilovevideoeditor-sdk/models/render_job.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @job_id.nil? return false if @status.nil? true end |