Class: ILoveVideoEditor::Template
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::Template
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/template.rb
Overview
Full template including its preset configuration or project builder metadata.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#accent_color ⇒ Object
Returns the value of attribute accent_color.
-
#description ⇒ Object
Returns the value of attribute description.
-
#icon ⇒ Object
Returns the value of attribute icon.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#tool_id ⇒ Object
Returns the value of attribute tool_id.
-
#variables_schema ⇒ Object
Returns the value of attribute variables_schema.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Template
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Template
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::Template` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::Template`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'accent_color') self.accent_color = attributes[:'accent_color'] else self.accent_color = nil end if attributes.key?(:'icon') self.icon = attributes[:'icon'] else self.icon = nil end if attributes.key?(:'tool_id') self.tool_id = attributes[:'tool_id'] end if attributes.key?(:'variables_schema') if (value = attributes[:'variables_schema']).is_a?(Array) self.variables_schema = value end end end |
Instance Attribute Details
#accent_color ⇒ Object
Returns the value of attribute accent_color.
27 28 29 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 27 def accent_color @accent_color end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 23 def description @description end |
#icon ⇒ Object
Returns the value of attribute icon.
29 30 31 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 29 def icon @icon end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 19 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 21 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
25 26 27 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 25 def platform @platform end |
#tool_id ⇒ Object
Returns the value of attribute tool_id.
31 32 33 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 31 def tool_id @tool_id end |
#variables_schema ⇒ Object
Returns the value of attribute variables_schema.
33 34 35 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 33 def variables_schema @variables_schema end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 58 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'platform' => :'platform', :'accent_color' => :'accentColor', :'icon' => :'icon', :'tool_id' => :'toolId', :'variables_schema' => :'variablesSchema' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 286 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 100 101 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 96 def self.openapi_nullable Set.new([ :'tool_id', :'variables_schema' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 82 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'platform' => :'String', :'accent_color' => :'String', :'icon' => :'String', :'tool_id' => :'String', :'variables_schema' => :'Array<Hash<String, Object>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 258 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && platform == o.platform && accent_color == o.accent_color && icon == o.icon && tool_id == o.tool_id && variables_schema == o.variables_schema end |
#eql?(o) ⇒ Boolean
273 274 275 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 273 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 279 def hash [id, name, description, platform, accent_color, icon, tool_id, variables_schema].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if @accent_color.nil? invalid_properties.push('invalid value for "accent_color", accent_color cannot be nil.') end if @icon.nil? invalid_properties.push('invalid value for "icon", icon cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/generated/ilovevideoeditor-sdk/models/template.rb', line 194 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @platform.nil? platform_validator = EnumAttributeValidator.new('String', ["youtube", "tiktok", "instagram", "general"]) return false unless platform_validator.valid?(@platform) return false if @accent_color.nil? return false if @icon.nil? true end |