Class: ILoveVideoEditor::ToolsApi
- Inherits:
-
Object
- Object
- ILoveVideoEditor::ToolsApi
- Defined in:
- lib/generated/ilovevideoeditor-sdk/api/tools_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#download_tool_job(id, opts = {}) ⇒ nil
Download a completed tool job result Redirects to the CDN or signed URL for the completed output file.
-
#download_tool_job_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Download a completed tool job result Redirects to the CDN or signed URL for the completed output file.
-
#get_tool_job(id, opts = {}) ⇒ ToolJobStatus
Get tool job status.
-
#get_tool_job_with_http_info(id, opts = {}) ⇒ Array<(ToolJobStatus, Integer, Hash)>
Get tool job status.
-
#initialize(api_client = ApiClient.default) ⇒ ToolsApi
constructor
A new instance of ToolsApi.
-
#queue_tool_job(tool_id, tool_job_request, opts = {}) ⇒ ToolJobStatus
Queue a cloud tool job Submit a public or presigned input URL and tool-specific configuration.
-
#queue_tool_job_with_http_info(tool_id, tool_job_request, opts = {}) ⇒ Array<(ToolJobStatus, Integer, Hash)>
Queue a cloud tool job Submit a public or presigned input URL and tool-specific configuration.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/generated/ilovevideoeditor-sdk/api/tools_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#download_tool_job(id, opts = {}) ⇒ nil
Download a completed tool job result Redirects to the CDN or signed URL for the completed output file.
27 28 29 30 |
# File 'lib/generated/ilovevideoeditor-sdk/api/tools_api.rb', line 27 def download_tool_job(id, opts = {}) download_tool_job_with_http_info(id, opts) nil end |
#download_tool_job_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Download a completed tool job result Redirects to the CDN or signed URL for the completed output file.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/generated/ilovevideoeditor-sdk/api/tools_api.rb', line 37 def download_tool_job_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ToolsApi.download_tool_job ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ToolsApi.download_tool_job" end # resource path local_var_path = '/v1/tools/jobs/{id}/download'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"ToolsApi.download_tool_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ToolsApi#download_tool_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_tool_job(id, opts = {}) ⇒ ToolJobStatus
Get tool job status
89 90 91 92 |
# File 'lib/generated/ilovevideoeditor-sdk/api/tools_api.rb', line 89 def get_tool_job(id, opts = {}) data, _status_code, _headers = get_tool_job_with_http_info(id, opts) data end |
#get_tool_job_with_http_info(id, opts = {}) ⇒ Array<(ToolJobStatus, Integer, Hash)>
Get tool job status
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/generated/ilovevideoeditor-sdk/api/tools_api.rb', line 98 def get_tool_job_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ToolsApi.get_tool_job ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ToolsApi.get_tool_job" end # resource path local_var_path = '/v1/tools/jobs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ToolJobStatus' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"ToolsApi.get_tool_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ToolsApi#get_tool_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#queue_tool_job(tool_id, tool_job_request, opts = {}) ⇒ ToolJobStatus
Queue a cloud tool job Submit a public or presigned input URL and tool-specific configuration. Simple tools run on a native ffmpeg worker; studio tools fall back to the full render pipeline.
152 153 154 155 |
# File 'lib/generated/ilovevideoeditor-sdk/api/tools_api.rb', line 152 def queue_tool_job(tool_id, tool_job_request, opts = {}) data, _status_code, _headers = queue_tool_job_with_http_info(tool_id, tool_job_request, opts) data end |
#queue_tool_job_with_http_info(tool_id, tool_job_request, opts = {}) ⇒ Array<(ToolJobStatus, Integer, Hash)>
Queue a cloud tool job Submit a public or presigned input URL and tool-specific configuration. Simple tools run on a native ffmpeg worker; studio tools fall back to the full render pipeline.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/generated/ilovevideoeditor-sdk/api/tools_api.rb', line 163 def queue_tool_job_with_http_info(tool_id, tool_job_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ToolsApi.queue_tool_job ...' end # verify the required parameter 'tool_id' is set if @api_client.config.client_side_validation && tool_id.nil? fail ArgumentError, "Missing the required parameter 'tool_id' when calling ToolsApi.queue_tool_job" end # verify the required parameter 'tool_job_request' is set if @api_client.config.client_side_validation && tool_job_request.nil? fail ArgumentError, "Missing the required parameter 'tool_job_request' when calling ToolsApi.queue_tool_job" end # resource path local_var_path = '/v1/tools/{toolId}/jobs'.sub('{toolId}', CGI.escape(tool_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(tool_job_request) # return_type return_type = opts[:debug_return_type] || 'ToolJobStatus' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth', 'BearerAuth'] = opts.merge( :operation => :"ToolsApi.queue_tool_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ToolsApi#queue_tool_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |