Class: ILoveVideoEditor::WorkflowRun
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ILoveVideoEditor::WorkflowRun
- Defined in:
- lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb
Instance Attribute Summary collapse
-
#completed_at ⇒ Object
Returns the value of attribute completed_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#error ⇒ Object
Returns the value of attribute error.
-
#estimated_cost ⇒ Object
Returns the value of attribute estimated_cost.
-
#id ⇒ Object
Returns the value of attribute id.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#total_cost ⇒ Object
Returns the value of attribute total_cost.
-
#trigger ⇒ Object
Returns the value of attribute trigger.
-
#triggered_by ⇒ Object
Returns the value of attribute triggered_by.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#variables ⇒ Object
Returns the value of attribute variables.
-
#workflow_id ⇒ Object
Returns the value of attribute workflow_id.
-
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkflowRun
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WorkflowRun
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ILoveVideoEditor::WorkflowRun` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ILoveVideoEditor::WorkflowRun`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'workflow_id') self.workflow_id = attributes[:'workflow_id'] else self.workflow_id = nil end if attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] else self.workspace_id = nil end if attributes.key?(:'triggered_by') self.triggered_by = attributes[:'triggered_by'] end if attributes.key?(:'trigger') self.trigger = attributes[:'trigger'] else self.trigger = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'variables') self.variables = attributes[:'variables'] else self.variables = nil end if attributes.key?(:'estimated_cost') self.estimated_cost = attributes[:'estimated_cost'] end if attributes.key?(:'total_cost') self.total_cost = attributes[:'total_cost'] end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#completed_at ⇒ Object
Returns the value of attribute completed_at.
40 41 42 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 40 def completed_at @completed_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
42 43 44 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 42 def created_at @created_at end |
#error ⇒ Object
Returns the value of attribute error.
36 37 38 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 36 def error @error end |
#estimated_cost ⇒ Object
Returns the value of attribute estimated_cost.
32 33 34 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 32 def estimated_cost @estimated_cost end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 18 def id @id end |
#started_at ⇒ Object
Returns the value of attribute started_at.
38 39 40 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 38 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
28 29 30 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 28 def status @status end |
#total_cost ⇒ Object
Returns the value of attribute total_cost.
34 35 36 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 34 def total_cost @total_cost end |
#trigger ⇒ Object
Returns the value of attribute trigger.
26 27 28 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 26 def trigger @trigger end |
#triggered_by ⇒ Object
Returns the value of attribute triggered_by.
24 25 26 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 24 def triggered_by @triggered_by end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
44 45 46 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 44 def updated_at @updated_at end |
#variables ⇒ Object
Returns the value of attribute variables.
30 31 32 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 30 def variables @variables end |
#workflow_id ⇒ Object
Returns the value of attribute workflow_id.
20 21 22 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 20 def workflow_id @workflow_id end |
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
22 23 24 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 22 def workspace_id @workspace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 47 def self.attribute_map { :'id' => :'id', :'workflow_id' => :'workflowId', :'workspace_id' => :'workspaceId', :'triggered_by' => :'triggeredBy', :'trigger' => :'trigger', :'status' => :'status', :'variables' => :'variables', :'estimated_cost' => :'estimatedCost', :'total_cost' => :'totalCost', :'error' => :'error', :'started_at' => :'startedAt', :'completed_at' => :'completedAt', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 334 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 105 106 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 97 def self.openapi_nullable Set.new([ :'triggered_by', :'estimated_cost', :'total_cost', :'error', :'started_at', :'completed_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 77 def self.openapi_types { :'id' => :'String', :'workflow_id' => :'String', :'workspace_id' => :'String', :'triggered_by' => :'String', :'trigger' => :'String', :'status' => :'String', :'variables' => :'Object', :'estimated_cost' => :'Float', :'total_cost' => :'Float', :'error' => :'String', :'started_at' => :'Time', :'completed_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 300 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && workflow_id == o.workflow_id && workspace_id == o.workspace_id && triggered_by == o.triggered_by && trigger == o.trigger && status == o.status && variables == o.variables && estimated_cost == o.estimated_cost && total_cost == o.total_cost && error == o.error && started_at == o.started_at && completed_at == o.completed_at && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
321 322 323 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 321 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
327 328 329 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 327 def hash [id, workflow_id, workspace_id, triggered_by, trigger, status, variables, estimated_cost, total_cost, error, started_at, completed_at, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @workflow_id.nil? invalid_properties.push('invalid value for "workflow_id", workflow_id cannot be nil.') end if @workspace_id.nil? invalid_properties.push('invalid value for "workspace_id", workspace_id cannot be nil.') end if @trigger.nil? invalid_properties.push('invalid value for "trigger", trigger cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @variables.nil? invalid_properties.push('invalid value for "variables", variables cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
227 228 229 230 231 232 233 234 235 236 |
# File 'lib/generated/ilovevideoeditor-sdk/models/workflow_run.rb', line 227 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @workflow_id.nil? return false if @workspace_id.nil? return false if @trigger.nil? return false if @status.nil? return false if @variables.nil? true end |